module max2
(
    input           clock,
    input   [3:0]   key,
    output  [7:0]   led,
    output          f0, f1, f2,
    output          f3, f4, f5,
    output          dp, dn, pt
);

assign led = din[7:0];
assign {dp, dn, pt} = 3'b000;
assign {f0, f1, f2, f3, f4, f5} = 6'b000_000;

// -----------------------------------------------------------------------------
// Контроллер памяти
// -----------------------------------------------------------------------------

wire        read = 1'b1;
wire        ready;
wire [15:0] din;

ufmreader U1
(
    .osc        (osc),

    // Запрос
    .read       (read),
    .address    ({5'h0, ~key[3:2]}),
    .din        (din),
    .ready      (ready),

    // PHY
    .ardin      (ardin),
    .arclk      (arclk),
    .drclk      (drclk),
    .drshft     (drshft),
    .drdout     (drdout)
);

// -----------------------------------------------------------------------------
// User Flash Memory
// -----------------------------------------------------------------------------

wire osc,   arclk,   drclk;
wire ardin, drdout,  drshft;
wire erase, program, busy;

ufm UFM0
(
    .osc        (osc),
    .arclk      (arclk),
    .drclk      (drclk),
    .ardin      (ardin),    // Данные для адреса
    .drdout     (drdout),   // Выходные данные
    .drshft     (drshft),   // 0: Защелка, 1: Задвижка
    .arshft     (1'b1),     // Тип адреса 0=Инкремент 1=Последовательный доступ
    .drdin      (1'b0),     // Данные для программирования Flash
    .program    (program),
    .erase      (erase),
    .busy       (busy),
    .rtpbusy    (rtpbusy),
);


endmodule
