// ---------------------------------------------------------------------
// Модуль для чтения из UFM
// Для извлечения 16 бит данных тратится 25 тактов (9A+16D)
// Пропускная способность на 8 Мгц примерно ~615 килобайт в сек
// ---------------------------------------------------------------------

module ufmreader
(
    input               osc,

    // Запрос
    input               read,           // Читать из памяти
    input       [8:0]   address,        // Адрес для чтения
    output  reg [15:0]  din,            // Принятые данные из UFM
    output  reg         ready,

    // Интерфейс для работы с UFM
    output              arclk,
    output              drclk,
    input               drdout,
    output  reg         ardin,
    output  reg         drshft
);

initial begin ready = 1'b0; ardin = 1'b0; drshft = 1'b0; end

assign  arclk   = ar_ena & osc;
assign  drclk   = dr_ena & osc;

reg         in_use  = 1'b0;
reg         ar_ena  = 1'b0;
reg         dr_ena  = 1'b0;
reg [4:0]   cnt     = 1'b0;
reg [8:0]   ar_addr = 1'b0;

always @(negedge osc)
begin

    // Добавляется всегда, кроме CNT=0
    cnt <= cnt ? cnt + 1'b1 : 1'b0;

    case (cnt)

        // IDLE статус. Читается только при изменении адреса
        0: if (read && (address != ar_addr || ~in_use)) begin

            ready   <= 1'b0;
            cnt     <= 1'b1;
            ar_ena  <= 1'b1;
            dr_ena  <= 1'b0;
            in_use  <= 1'b1;
            ar_addr <= address;
            ardin   <= address[8];

        end else ready <= 1'b1;

        // Задвигается адрес
        1,2,3,4,5,6,7,8: ardin <= ar_addr[8 - cnt];

        // Защелкивание данных
        9: begin {drshft, ar_ena, dr_ena} <= 3'b001; end

        // Завершение принятия данных
        8'h19: begin din <= {din[14:0], drdout}; dr_ena <= 1'b0; cnt <= 1'b0; end

        // Получение старших 15 битов
        default: begin din <= {din[14:0], drdout}; if (cnt == 10) drshft <= 1'b1; end

    endcase

end

endmodule
